@@ -94,21 +94,23 @@ xsltDocumentFunction(xmlXPathParserContextPtr ctxt, int nargs){
 	obj = valuePop(ctxt);
 	ret = xmlXPathNewNodeSet(NULL);
 
-	for (i = 0; i < obj->nodesetval->nodeNr; i++) {
-	    valuePush(ctxt,
-		      xmlXPathNewNodeSet(obj->nodesetval->nodeTab[i]));
-	    xmlXPathStringFunction(ctxt, 1);
-	    if (nargs == 2) {
-		valuePush(ctxt, xmlXPathObjectCopy(obj2));
-	    } else {
+	if (obj->nodesetval) {
+	    for (i = 0; i < obj->nodesetval->nodeNr; i++) {
 		valuePush(ctxt,
 			  xmlXPathNewNodeSet(obj->nodesetval->nodeTab[i]));
+		xmlXPathStringFunction(ctxt, 1);
+		if (nargs == 2) {
+		    valuePush(ctxt, xmlXPathObjectCopy(obj2));
+		} else {
+		    valuePush(ctxt,
+			      xmlXPathNewNodeSet(obj->nodesetval->nodeTab[i]));
+		}
+		xsltDocumentFunction(ctxt, 2);
+		newobj = valuePop(ctxt);
+		ret->nodesetval = xmlXPathNodeSetMerge(ret->nodesetval,
+						       newobj->nodesetval);
+		xmlXPathFreeObject(newobj);
 	    }
-	    xsltDocumentFunction(ctxt, 2);
-	    newobj = valuePop(ctxt);
-	    ret->nodesetval = xmlXPathNodeSetMerge(ret->nodesetval,
-						   newobj->nodesetval);
-	    xmlXPathFreeObject(newobj);
 	}
 
 	xmlXPathFreeObject(obj);
@@ -138,7 +140,8 @@ xsltDocumentFunction(xmlXPathParserContextPtr ctxt, int nargs){
 	    base = xmlNodeGetBase(obj2->nodesetval->nodeTab[0]->doc,
 				  obj->nodesetval->nodeTab[0]);
 	} else {
-	    base = xmlNodeGetBase(ctxt->context->doc,
+	    base = xmlNodeGetBase(
+		((xsltTransformContextPtr)ctxt->context->extra)->style->doc,
 				  ctxt->context->node);
 	}
 	URI = xmlBuildURI(obj->stringval, base);
@@ -184,7 +187,7 @@ void
 xsltKeyFunction(xmlXPathParserContextPtr ctxt, int nargs){
     xmlNodeSetPtr nodelist;
     xmlXPathObjectPtr obj1, obj2;
-    xmlChar *key, *value;
+    xmlChar *key = NULL, *value;
     const xmlChar *keyURI;
     xsltTransformContextPtr tctxt;
 
@@ -215,15 +218,17 @@ xsltKeyFunction(xmlXPathParserContextPtr ctxt, int nargs){
 
 	ret = xmlXPathNewNodeSet(NULL);
 
-	for (i = 0; i < obj2->nodesetval->nodeNr; i++) {
-	    valuePush(ctxt, xmlXPathObjectCopy(obj1));
-	    valuePush(ctxt,
-		      xmlXPathNewNodeSet(obj2->nodesetval->nodeTab[i]));
-	    xsltKeyFunction(ctxt, 2);
-	    newobj = valuePop(ctxt);
-	    ret->nodesetval = xmlXPathNodeSetMerge(ret->nodesetval,
-						   newobj->nodesetval);
-	    xmlXPathFreeObject(newobj);
+	if (obj2->nodesetval != NULL) {
+	    for (i = 0; i < obj2->nodesetval->nodeNr; i++) {
+		valuePush(ctxt, xmlXPathObjectCopy(obj1));
+		valuePush(ctxt,
+			  xmlXPathNewNodeSet(obj2->nodesetval->nodeTab[i]));
+		xsltKeyFunction(ctxt, 2);
+		newobj = valuePop(ctxt);
+		ret->nodesetval = xmlXPathNodeSetMerge(ret->nodesetval,
+						       newobj->nodesetval);
+		xmlXPathFreeObject(newobj);
+	    }
 	}
 	valuePush(ctxt, ret);
     } else {
@@ -449,7 +454,7 @@ void
 xsltSystemPropertyFunction(xmlXPathParserContextPtr ctxt, int nargs){
     xmlXPathObjectPtr obj;
     xmlChar *prefix, *name;
-    const xmlChar *nsURI;
+    const xmlChar *nsURI = NULL;
 
     if (nargs != 1) {
         xsltGenericError(xsltGenericErrorContext,
@@ -541,7 +546,7 @@ void
 xsltFunctionAvailableFunction(xmlXPathParserContextPtr ctxt, int nargs){
     xmlXPathObjectPtr obj;
     xmlChar *prefix, *name;
-    const xmlChar *nsURI;
+    const xmlChar *nsURI = NULL;
 
     if (nargs != 1) {
         xsltGenericError(xsltGenericErrorContext,
@@ -589,7 +594,7 @@ xsltFunctionAvailableFunction(xmlXPathParserContextPtr ctxt, int nargs){
  * Implement the current() XSLT function
  *   node-set current()
  */
-void
+static void
 xsltCurrentFunction(xmlXPathParserContextPtr ctxt, int nargs){
     xsltTransformContextPtr tctxt;
 
