@@ -101,8 +101,8 @@ scope type name##Pop(xsltTransformContextPtr ctxt) {			\
 /*
  * Those macros actually generate the functions
  */
-PUSH_AND_POP(extern, xsltTemplatePtr, templ)
-PUSH_AND_POP(extern, xsltStackElemPtr, vars)
+PUSH_AND_POP(static, xsltTemplatePtr, templ)
+PUSH_AND_POP(static, xsltStackElemPtr, vars)
 
 /************************************************************************
  *									*
@@ -119,7 +119,7 @@ PUSH_AND_POP(extern, xsltStackElemPtr, vars)
  *
  * Returns the newly allocated xsltTransformContextPtr or NULL in case of error
  */
-xsltTransformContextPtr
+static xsltTransformContextPtr
 xsltNewTransformContext(xsltStylesheetPtr style, xmlDocPtr doc) {
     xsltTransformContextPtr cur;
     xsltDocumentPtr docu;
@@ -174,6 +174,8 @@ xsltNewTransformContext(xsltStylesheetPtr style, xmlDocPtr doc) {
 	xmlFree(cur);
 	return(NULL);
     }
+    cur->xpathCtxt->proximityPosition = 0;
+    cur->xpathCtxt->contextSize = 0;
     XSLT_REGISTER_VARIABLE_LOOKUP(cur);
     cur->xpathCtxt->nsHash = style->nsHash;
     docu = xsltNewDocument(cur, doc);
@@ -196,7 +198,7 @@ xsltNewTransformContext(xsltStylesheetPtr style, xmlDocPtr doc) {
  *
  * Free up the memory allocated by @ctxt
  */
-void
+static void
 xsltFreeTransformContext(xsltTransformContextPtr ctxt) {
     if (ctxt == NULL)
 	return;
@@ -234,7 +236,7 @@ xmlNodePtr xsltCopyTree(xsltTransformContextPtr ctxt, xmlNodePtr node,
  *
  * Returns: a new xmlAttrPtr, or NULL in case of error.
  */
-xmlAttrPtr
+static xmlAttrPtr
 xsltCopyProp(xsltTransformContextPtr ctxt, xmlNodePtr target,
 	     xmlAttrPtr attr) {
     xmlAttrPtr ret = NULL;
@@ -266,7 +268,7 @@ xsltCopyProp(xsltTransformContextPtr ctxt, xmlNodePtr target,
  *
  * Returns: a new xmlAttrPtr, or NULL in case of error.
  */
-xmlAttrPtr
+static xmlAttrPtr
 xsltCopyPropList(xsltTransformContextPtr ctxt, xmlNodePtr target,
 	         xmlAttrPtr cur) {
     xmlAttrPtr ret = NULL;
@@ -306,7 +308,7 @@ xsltCopyPropList(xsltTransformContextPtr ctxt, xmlNodePtr target,
  *
  * Returns a pointer to the new node, or NULL in case of error
  */
-xmlNodePtr
+static xmlNodePtr
 xsltCopyNode(xsltTransformContextPtr ctxt, xmlNodePtr node,
 	     xmlNodePtr insert) {
     xmlNodePtr copy;
@@ -343,7 +345,7 @@ xsltCopyNode(xsltTransformContextPtr ctxt, xmlNodePtr node,
  *
  * Returns a pointer to the new list, or NULL in case of error
  */
-xmlNodePtr
+static xmlNodePtr
 xsltCopyTreeList(xsltTransformContextPtr ctxt, xmlNodePtr list,
 	     xmlNodePtr insert) {
     xmlNodePtr copy, ret = NULL, last = NULL;
@@ -432,7 +434,7 @@ void xsltProcessOneNode(xsltTransformContextPtr ctxt, xmlNodePtr node);
  * the built-in template rule is the only template rule that is applied
  * for namespace nodes.
  */
-void
+static void
 xsltDefaultProcessOneNode(xsltTransformContextPtr ctxt, xmlNodePtr node) {
     xmlNodePtr copy;
     xmlAttrPtr attrs;
@@ -464,9 +466,7 @@ xsltDefaultProcessOneNode(xsltTransformContextPtr ctxt, xmlNodePtr node) {
 		oldNode = ctxt->node;
 		ctxt->node = node;
 		templPush(ctxt, template);
-		varsPush(ctxt, NULL);
 		xsltApplyOneTemplate(ctxt, node, template->content, 1);
-		xsltFreeStackElemList(varsPop(ctxt));
 		templPop(ctxt);
 		ctxt->node = oldNode;
 	    } else /* if (ctxt->mode == NULL) */ {
@@ -497,9 +497,7 @@ xsltDefaultProcessOneNode(xsltTransformContextPtr ctxt, xmlNodePtr node) {
 		oldNode = ctxt->node;
 		ctxt->node = node;
 		templPush(ctxt, template);
-		varsPush(ctxt, NULL);
 		xsltApplyOneTemplate(ctxt, node, template->content, 1);
-		xsltFreeStackElemList(varsPop(ctxt));
 		templPop(ctxt);
 		ctxt->node = oldNode;
 	    } else /* if (ctxt->mode == NULL) */ {
@@ -523,7 +521,7 @@ xsltDefaultProcessOneNode(xsltTransformContextPtr ctxt, xmlNodePtr node) {
 	    return;
 	case XML_ATTRIBUTE_NODE:
 	    if (ctxt->insert->type == XML_ELEMENT_NODE) {
-		    xmlAttrPtr attr = (xmlAttrPtr) node, ret = NULL, cur;
+		    xmlAttrPtr attr = (xmlAttrPtr) node, ret = NULL, current;
 		template = xsltGetTemplate(ctxt, node, NULL);
 		if (template) {
 		    xmlNodePtr oldNode;
@@ -531,9 +529,7 @@ xsltDefaultProcessOneNode(xsltTransformContextPtr ctxt, xmlNodePtr node) {
 		    oldNode = ctxt->node;
 		    ctxt->node = node;
 		    templPush(ctxt, template);
-		    varsPush(ctxt, NULL);
 		    xsltApplyOneTemplate(ctxt, node, template->content, 1);
-		    xsltFreeStackElemList(varsPop(ctxt));
 		    templPop(ctxt);
 		    ctxt->node = oldNode;
 		} else if (ctxt->mode == NULL) {
@@ -548,12 +544,12 @@ xsltDefaultProcessOneNode(xsltTransformContextPtr ctxt, xmlNodePtr node) {
 		    } else
 			ret = xmlCopyProp(ctxt->insert, attr);
 
-		    cur = ctxt->insert->properties;
-		    if (cur != NULL) {
-			while (cur->next != NULL)
-			    cur = cur->next;
-			cur->next = ret;
-			ret->prev = cur;
+		    current = ctxt->insert->properties;
+		    if (current != NULL) {
+			while (current->next != NULL)
+			    current = current->next;
+			current->next = ret;
+			ret->prev = current;
 		    }else
 			ctxt->insert->properties = ret;
 		}
@@ -585,8 +581,6 @@ xsltDefaultProcessOneNode(xsltTransformContextPtr ctxt, xmlNodePtr node) {
 	    case XML_DOCUMENT_NODE:
 	    case XML_HTML_DOCUMENT_NODE:
 	    case XML_ELEMENT_NODE:
-		nbchild++;
-		break;
 	    case XML_PI_NODE:
 	    case XML_COMMENT_NODE:
 		nbchild++;
@@ -622,9 +616,7 @@ xsltDefaultProcessOneNode(xsltTransformContextPtr ctxt, xmlNodePtr node) {
 	    oldNode = ctxt->node;
 	    ctxt->node = node;
 	    templPush(ctxt, template);
-	    varsPush(ctxt, NULL);
 	    xsltApplyOneTemplate(ctxt, node, template->content, 1);
-	    xsltFreeStackElemList(varsPop(ctxt));
 	    templPop(ctxt);
 	    ctxt->node = oldNode;
 	}
@@ -641,7 +633,9 @@ xsltDefaultProcessOneNode(xsltTransformContextPtr ctxt, xmlNodePtr node) {
 	    case XML_ELEMENT_NODE:
 		ctxt->xpathCtxt->contextSize = nbchild;
 		ctxt->xpathCtxt->proximityPosition = childno;
+		varsPush( ctxt, NULL );
 		xsltProcessOneNode(ctxt, cur);
+		xsltFreeStackElemList( varsPop(ctxt) );
 		break;
 	    case XML_CDATA_SECTION_NODE:
 		template = xsltGetTemplate(ctxt, node, NULL);
@@ -656,9 +650,7 @@ xsltDefaultProcessOneNode(xsltTransformContextPtr ctxt, xmlNodePtr node) {
 		    oldNode = ctxt->node;
 		    ctxt->node = node;
 		    templPush(ctxt, template);
-		    varsPush(ctxt, NULL);
 		    xsltApplyOneTemplate(ctxt, node, template->content, 1);
-		    xsltFreeStackElemList(varsPop(ctxt));
 		    templPop(ctxt);
 		    ctxt->node = oldNode;
 		} else /* if (ctxt->mode == NULL) */ {
@@ -691,9 +683,7 @@ xsltDefaultProcessOneNode(xsltTransformContextPtr ctxt, xmlNodePtr node) {
 		    ctxt->xpathCtxt->contextSize = nbchild;
 		    ctxt->xpathCtxt->proximityPosition = childno;
 		    templPush(ctxt, template);
-		    varsPush(ctxt, NULL);
 		    xsltApplyOneTemplate(ctxt, cur, template->content, 1);
-		    xsltFreeStackElemList(varsPop(ctxt));
 		    templPop(ctxt);
 		    ctxt->node = oldNode;
 		} else /* if (ctxt->mode == NULL) */ {
@@ -726,9 +716,7 @@ xsltDefaultProcessOneNode(xsltTransformContextPtr ctxt, xmlNodePtr node) {
 		    ctxt->xpathCtxt->contextSize = nbchild;
 		    ctxt->xpathCtxt->proximityPosition = childno;
 		    templPush(ctxt, template);
-		    varsPush(ctxt, NULL);
 		    xsltApplyOneTemplate(ctxt, cur, template->content, 1);
-		    xsltFreeStackElemList(varsPop(ctxt));
 		    templPop(ctxt);
 		    ctxt->node = oldNode;
 		}
@@ -808,9 +796,7 @@ xsltProcessOneNode(xsltTransformContextPtr ctxt, xmlNodePtr node) {
 	                 node->name);
 #endif
 	templPush(ctxt, template);
-	varsPush(ctxt, NULL);
 	xsltApplyOneTemplate(ctxt, node, template->content, 1);
-	xsltFreeStackElemList(varsPop(ctxt));
 	templPop(ctxt);
     } else {
 #ifdef DEBUG_PROCESS
@@ -824,9 +810,7 @@ xsltProcessOneNode(xsltTransformContextPtr ctxt, xmlNodePtr node) {
 	oldNode = ctxt->node;
 	ctxt->node = node;
 	templPush(ctxt, template);
-	varsPush(ctxt, NULL);
 	xsltApplyOneTemplate(ctxt, node, template->content, 1);
-	xsltFreeStackElemList(varsPop(ctxt));
 	templPop(ctxt);
 	ctxt->node = oldNode;
     }
@@ -982,10 +966,10 @@ xsltApplyOneTemplate(xsltTransformContextPtr ctxt, xmlNodePtr node,
 		attrs = xsltAttrListTemplateProcess(ctxt, copy,
 			                            cur->properties);
 		if (copy->properties != NULL) {
-		    xmlAttrPtr cur = copy->properties;
-		    while (cur->next != NULL)
-			cur = cur->next;
-		    cur->next = attrs;
+		    xmlAttrPtr current = copy->properties;
+		    while (current->next != NULL)
+			current = current->next;
+		    current->next = attrs;
 		} else
 		    copy->properties = attrs;
 	    }
@@ -1371,7 +1355,7 @@ xsltCopy(xsltTransformContextPtr ctxt, xmlNodePtr node,
  * Process the xslt text node on the source node
  */
 void
-xsltText(xsltTransformContextPtr ctxt, xmlNodePtr node,
+xsltText(xsltTransformContextPtr ctxt, xmlNodePtr node ATTRIBUTE_UNUSED,
 	    xmlNodePtr inst, xsltStylePreCompPtr comp) {
     xmlNodePtr copy;
 
@@ -1639,11 +1623,12 @@ error:
  */
 void
 xsltComment(xsltTransformContextPtr ctxt, xmlNodePtr node,
-	           xmlNodePtr inst, xsltStylePreCompPtr comp) {
+	           xmlNodePtr inst, xsltStylePreCompPtr comp ATTRIBUTE_UNUSED) {
     xmlChar *value = NULL;
     xmlNodePtr comment;
 
     value = xsltEvalTemplateString(ctxt, node, inst);
+    /* TODO: use or generate the compiled form */
     /* TODO: check that there is no -- sequence and doesn't end up with - */
 #ifdef DEBUG_PROCESS
     if (value == NULL)
@@ -1734,6 +1719,7 @@ xsltCopyOf(xsltTransformContextPtr ctxt, xmlNodePtr node,
     xmlNodePtr copy = NULL;
     xmlNodeSetPtr list = NULL;
     int i;
+    int oldProximityPosition, oldContextSize;
 
     if ((ctxt == NULL) || (node == NULL) || (inst == NULL))
 	return;
@@ -1750,8 +1736,12 @@ xsltCopyOf(xsltTransformContextPtr ctxt, xmlNodePtr node,
 	 "xsltCopyOf: select %s\n", comp->select);
 #endif
 
+    oldProximityPosition = ctxt->xpathCtxt->proximityPosition;
+    oldContextSize = ctxt->xpathCtxt->contextSize;
     ctxt->xpathCtxt->node = node;
     res = xmlXPathCompiledEval(comp->comp, ctxt->xpathCtxt);
+    ctxt->xpathCtxt->proximityPosition = oldProximityPosition;
+    ctxt->xpathCtxt->contextSize = oldContextSize;
     if (res != NULL) {
 	if (res->type == XPATH_NODESET) {
 	    list = res->nodesetval;
@@ -1793,7 +1783,7 @@ xsltCopyOf(xsltTransformContextPtr ctxt, xmlNodePtr node,
 	    }
 	    if (copy == NULL) {
 		xsltGenericError(xsltGenericErrorContext,
-		    "xsltDefaultProcessOneNode: text copy failed\n");
+		    "xsltCopyOf: text copy failed\n");
 	    }
 #ifdef DEBUG_PROCESS
 	    else
@@ -1821,6 +1811,7 @@ xsltValueOf(xsltTransformContextPtr ctxt, xmlNodePtr node,
 	           xmlNodePtr inst, xsltStylePreCompPtr comp) {
     xmlXPathObjectPtr res = NULL;
     xmlNodePtr copy = NULL;
+    int oldProximityPosition, oldContextSize;
 
     if ((ctxt == NULL) || (node == NULL) || (inst == NULL) || (comp == NULL))
 	return;
@@ -1838,8 +1829,12 @@ xsltValueOf(xsltTransformContextPtr ctxt, xmlNodePtr node,
 	 "xsltValueOf: select %s\n", comp->select);
 #endif
 
+    oldProximityPosition = ctxt->xpathCtxt->proximityPosition;
+    oldContextSize = ctxt->xpathCtxt->contextSize;
     ctxt->xpathCtxt->node = node;
     res = xmlXPathCompiledEval(comp->comp, ctxt->xpathCtxt);
+    ctxt->xpathCtxt->proximityPosition = oldProximityPosition;
+    ctxt->xpathCtxt->contextSize = oldContextSize;
     if (res != NULL) {
 	if (res->type != XPATH_STRING)
 	    res = xmlXPathConvertString(res);
@@ -1903,7 +1898,7 @@ xsltNumber(xsltTransformContextPtr ctxt, xmlNodePtr node,
  */
 void
 xsltApplyImports(xsltTransformContextPtr ctxt, xmlNodePtr node,
-	         xmlNodePtr inst, xsltStylePreCompPtr comp) {
+	         xmlNodePtr inst ATTRIBUTE_UNUSED, xsltStylePreCompPtr comp ATTRIBUTE_UNUSED) {
     xsltTemplatePtr template;
 
     if ((ctxt->templ == NULL) || (ctxt->templ->style == NULL)) {
@@ -1960,8 +1955,10 @@ xsltCallTemplate(xsltTransformContextPtr ctxt, xmlNodePtr node,
 	if (IS_XSLT_ELEM(cur)) {
 	    if (IS_XSLT_NAME(cur, "with-param")) {
 		param = xsltParseStylesheetCallerParam(ctxt, cur);
-		param->next = params;
-		params = param;
+		if (param != NULL) {
+		    param->next = params;
+		    params = param;
+		}
 	    } else {
 		xsltGenericError(xsltGenericDebugContext,
 		     "xslt:call-template: misplaced xslt:%s\n", cur->name);
@@ -1990,13 +1987,13 @@ xsltCallTemplate(xsltTransformContextPtr ctxt, xmlNodePtr node,
 void
 xsltApplyTemplates(xsltTransformContextPtr ctxt, xmlNodePtr node,
 	           xmlNodePtr inst, xsltStylePreCompPtr comp) {
-    xmlNodePtr cur, delete = NULL;
+    xmlNodePtr cur, delete = NULL, oldnode;
     xmlXPathObjectPtr res = NULL;
     xmlNodeSetPtr list = NULL, oldlist;
     int i, oldProximityPosition, oldContextSize;
     const xmlChar *oldmode, *oldmodeURI;
     int have_sort=0;
-    xsltStackElemPtr params = NULL, param, lastParam = NULL;
+    xsltStackElemPtr params = NULL, param, tmp, p;
 
 
     if (comp == NULL) {
@@ -2014,6 +2011,7 @@ xsltApplyTemplates(xsltTransformContextPtr ctxt, xmlNodePtr node,
     /*
      * Get mode if any
      */
+    oldnode = ctxt->node;
     oldmode = ctxt->mode;
     oldmodeURI = ctxt->modeURI;
     ctxt->mode = comp->mode;
@@ -2030,13 +2028,20 @@ xsltApplyTemplates(xsltTransformContextPtr ctxt, xmlNodePtr node,
 	     "xsltApplyTemplates: select %s\n", comp->select);
 #endif
 
+	oldProximityPosition = ctxt->xpathCtxt->proximityPosition;
+	oldContextSize = ctxt->xpathCtxt->contextSize;
 	ctxt->xpathCtxt->node = node;
 	res = xmlXPathCompiledEval(comp->comp, ctxt->xpathCtxt);
+	ctxt->xpathCtxt->contextSize = oldContextSize;
+	ctxt->xpathCtxt->proximityPosition = oldProximityPosition;
 	if (res != NULL) {
 	    if (res->type == XPATH_NODESET) {
 		list = res->nodesetval;
 		res->nodesetval = NULL;
 	     } else {
+		list == NULL;
+	     }
+	     if (list == NULL) {
 #ifdef DEBUG_PROCESS
 		xsltGenericDebug(xsltGenericDebugContext,
 		    "xsltApplyTemplates: select didn't evaluate to a node list\n");
@@ -2096,6 +2101,7 @@ xsltApplyTemplates(xsltTransformContextPtr ctxt, xmlNodePtr node,
     }
 
 #ifdef DEBUG_PROCESS
+    if (list != NULL)
     xsltGenericDebug(xsltGenericDebugContext,
 	"xsltApplyTemplates: list of %d nodes\n", list->nodeNr);
 #endif
@@ -2115,9 +2121,10 @@ xsltApplyTemplates(xsltTransformContextPtr ctxt, xmlNodePtr node,
         if (IS_XSLT_ELEM(cur)) {
             if (IS_XSLT_NAME(cur, "with-param")) {
                 param = xsltParseStylesheetCallerParam(ctxt, cur);
-                param->next = params;
-                params = param;
-                if (lastParam==NULL) lastParam = params;
+		if (param != NULL) {
+		    param->next = params;
+		    params = param;
+		}
 	    } else if (IS_XSLT_NAME(cur, "sort")) {
 		if (!have_sort) {
 		    have_sort = 1;
@@ -2139,12 +2146,25 @@ xsltApplyTemplates(xsltTransformContextPtr ctxt, xmlNodePtr node,
     for (i = 0;i < list->nodeNr;i++) {
 	ctxt->node = list->nodeTab[i];
 	ctxt->xpathCtxt->proximityPosition = i + 1;
-	varsPush(ctxt,params);
+	varsPush(ctxt, params);
 	xsltProcessOneNode(ctxt, list->nodeTab[i]);
-	varsPop(ctxt);
-	if (lastParam != NULL) {
-	    xsltFreeStackElemList(lastParam->next);
-	    lastParam->next = NULL;
+	tmp = varsPop(ctxt);
+	/*
+	 * Free other parameter and variables which may have been
+	 * added to the set defined in the caller.
+	 */
+	if (params == NULL) {
+	    xsltFreeStackElemList(tmp);
+	} else if (tmp != params) {
+            p = tmp;
+	    while ((p != NULL) && (p->next != params))
+		p = p->next;
+	    if (p == NULL) {
+		xsltFreeStackElemList(tmp);
+	    } else {
+		p->next = NULL;
+		xsltFreeStackElemList(tmp);
+	    }
 	}
     }
     xsltFreeStackElemList(params);	/* free the parameter list */
@@ -2153,6 +2173,7 @@ xsltApplyTemplates(xsltTransformContextPtr ctxt, xmlNodePtr node,
     ctxt->xpathCtxt->proximityPosition = oldProximityPosition;
 
 error:
+    ctxt->node = oldnode;
     ctxt->mode = oldmode;
     ctxt->modeURI = oldmodeURI;
     if (res != NULL)
@@ -2173,11 +2194,12 @@ error:
  */
 void
 xsltChoose(xsltTransformContextPtr ctxt, xmlNodePtr node,
-	           xmlNodePtr inst, xsltStylePreCompPtr comp) {
+	   xmlNodePtr inst, xsltStylePreCompPtr comp ATTRIBUTE_UNUSED) {
     xmlChar *prop = NULL;
     xmlXPathObjectPtr res = NULL;
     xmlNodePtr replacement, when;
     int doit = 1;
+    int oldProximityPosition, oldContextSize;
 
     if ((ctxt == NULL) || (node == NULL) || (inst == NULL))
 	return;
@@ -2198,8 +2220,8 @@ xsltChoose(xsltTransformContextPtr ctxt, xmlNodePtr node,
 	goto error;
     }
     while (IS_XSLT_ELEM(replacement) && (IS_XSLT_NAME(replacement, "when"))) {
-	xmlXPathCompExprPtr comp;
-        /* TODO: build a precompiled block for when too ! */
+	xmlXPathCompExprPtr xpathComp;
+        /* TODO: build a prexpathCompiled block for when too ! */
 	when = replacement;
 	prop = xmlGetNsProp(when, (const xmlChar *)"test", XSLT_NAMESPACE);
 	if (prop == NULL) {
@@ -2212,12 +2234,16 @@ xsltChoose(xsltTransformContextPtr ctxt, xmlNodePtr node,
 	     "xsl:when: test %s\n", prop);
 #endif
 
-	comp = xmlXPathCompile(prop);
-	if (comp == NULL)
+	xpathComp = xmlXPathCompile(prop);
+	if (xpathComp == NULL)
 	    goto error;
-	ctxt->xpathCtxt->node = node;
-	res = xmlXPathCompiledEval(comp, ctxt->xpathCtxt);
-	xmlXPathFreeCompExpr(comp);
+	oldProximityPosition = ctxt->xpathCtxt->proximityPosition;
+	oldContextSize = ctxt->xpathCtxt->contextSize;
+  	ctxt->xpathCtxt->node = node;
+  	res = xmlXPathCompiledEval(xpathComp, ctxt->xpathCtxt);
+	xmlXPathFreeCompExpr(xpathComp);
+	ctxt->xpathCtxt->proximityPosition = oldProximityPosition;
+	ctxt->xpathCtxt->contextSize = oldContextSize;
 	if (res != NULL) {
 	    if (res->type != XPATH_BOOLEAN)
 		res = xmlXPathConvertBoolean(res);
@@ -2288,6 +2314,7 @@ xsltIf(xsltTransformContextPtr ctxt, xmlNodePtr node,
 	           xmlNodePtr inst, xsltStylePreCompPtr comp) {
     xmlXPathObjectPtr res = NULL;
     int doit = 1;
+    int oldContextSize, oldProximityPosition;
 
     if (comp == NULL) {
 	xsltStylePreCompute(ctxt, inst);
@@ -2309,8 +2336,12 @@ xsltIf(xsltTransformContextPtr ctxt, xmlNodePtr node,
 	 "xsltIf: test %s\n", comp->test);
 #endif
 
+    oldContextSize = ctxt->xpathCtxt->contextSize;
+    oldProximityPosition = ctxt->xpathCtxt->proximityPosition;
     ctxt->xpathCtxt->node = node;
     res = xmlXPathCompiledEval(comp->comp, ctxt->xpathCtxt);
+    ctxt->xpathCtxt->contextSize = oldContextSize;
+    ctxt->xpathCtxt->proximityPosition = oldProximityPosition;
     if (res != NULL) {
 	if (res->type != XPATH_BOOLEAN)
 	    res = xmlXPathConvertBoolean(res);
@@ -2380,7 +2411,11 @@ xsltForEach(xsltTransformContextPtr ctxt, xmlNodePtr node,
 #endif
 
     ctxt->xpathCtxt->node = node;
+    oldProximityPosition = ctxt->xpathCtxt->proximityPosition;
+    oldContextSize = ctxt->xpathCtxt->contextSize;
     res = xmlXPathCompiledEval(comp->comp, ctxt->xpathCtxt);
+    ctxt->xpathCtxt->contextSize = oldContextSize;
+    ctxt->xpathCtxt->proximityPosition = oldProximityPosition;
     if (res != NULL) {
 	if (res->type == XPATH_NODESET)
 	    list = res->nodesetval;
@@ -2441,6 +2476,7 @@ error:
  * xsltApplyStylesheet:
  * @style:  a parsed XSLT stylesheet
  * @doc:  a parsed XML document
+ * @params:  a NULL terminated arry of parameters names/values tuples
  *
  * Apply the stylesheet to the document
  * NOTE: This may lead to a non-wellformed output XML wise !
@@ -2448,7 +2484,8 @@ error:
  * Returns the result document or NULL in case of error
  */
 xmlDocPtr
-xsltApplyStylesheet(xsltStylesheetPtr style, xmlDocPtr doc) {
+xsltApplyStylesheet(xsltStylesheetPtr style, xmlDocPtr doc,
+	            const char **params) {
     xmlDocPtr res = NULL;
     xsltTransformContextPtr ctxt = NULL;
     xmlNodePtr root;
@@ -2500,6 +2537,8 @@ xsltApplyStylesheet(xsltStylesheetPtr style, xmlDocPtr doc) {
      */
     ctxt->output = res;
     ctxt->insert = (xmlNodePtr) res;
+    if (params != NULL)
+	xsltEvalUserParams(ctxt, params);
     xsltEvalGlobalVariables(ctxt);
     ctxt->node = (xmlNodePtr) doc;
     varsPush(ctxt, NULL);
