@@ -255,8 +255,11 @@ struct _xsltStylePreComp {
 
     int      ver11;		/* document */
     xmlChar *filename;		/* document URL */
+    int      has_filename;	/* document */
 
     xsltNumberData numdata;	/* number */
+
+    xmlXPathCompExprPtr comp;	/* a precompiled XPath expression */
 };
 
 /*
